@@ -37,19 +37,27 @@ impl Rgba32 {
         ]
     }
 
-    pub fn with_r(self, r: u8) -> Self {
+    pub fn to_f32_array_rgb_01(self) -> [f32; 3] {
+        [
+            self.r as f32 / 255.,
+            self.g as f32 / 255.,
+            self.b as f32 / 255.,
+        ]
+    }
+
+    pub const fn with_r(self, r: u8) -> Self {
         Self { r, ..self }
     }
 
-    pub fn with_g(self, g: u8) -> Self {
+    pub const fn with_g(self, g: u8) -> Self {
         Self { g, ..self }
     }
 
-    pub fn with_b(self, b: u8) -> Self {
+    pub const fn with_b(self, b: u8) -> Self {
         Self { b, ..self }
     }
 
-    pub fn with_a(self, a: u8) -> Self {
+    pub const fn with_a(self, a: u8) -> Self {
         Self { a, ..self }
     }
 
@@ -85,6 +93,18 @@ impl Rgba32 {
             a: alpha_out,
         }
     }
+
+    pub const fn normalised_scalar_mul(self, scalar: u8) -> Self {
+        const fn single_channel(c: u8, scalar: u8) -> u8 {
+            ((c as u32 * scalar as u32) / 255) as u8
+        }
+        Self {
+            r: single_channel(self.r, scalar),
+            g: single_channel(self.g, scalar),
+            b: single_channel(self.b, scalar),
+            a: single_channel(self.a, scalar),
+        }
+    }
 }
 
 pub const fn rgba32(r: u8, g: u8, b: u8, a: u8) -> Rgba32 {
